pub enum ParsingBodyMechanism {
Default,
JustBytes,
FormData,
XWWWFormData,
}Expand description
Informs the context how incoming request body bytes should be parsed.
Variants
Default
Let the context determine the parsing strategy based on Content-Type header.
JustBytes
Keep incoming bytes raw without automatic parsing.
FormData
Parse incoming bytes into multipart form fields.
XWWWFormData
Parse incoming bytes into x-www-form-urlencoded structure.