IncomingRequest

Struct IncomingRequest 

pub struct IncomingRequest<'a, const HEADERS_COUNT: usize, const PATH_QUERY_COUNT: usize> { /* private fields */ }
a structr for holding references to buffer bytes with zero copy cost

Implementations

Source

impl<'a, const HEADERS_COUNT: usize, const PATH_QUERY_COUNT: usize> IncomingRequest<'a, HEADERS_COUNT, PATH_QUERY_COUNT>

pub fn get_total_headers_length(&self) -> usize

getting total headers length

pub fn first_line(&self) -> &HttpFirstLine<'a>

first line

pub fn headers(&self) -> &HttpHeaders<'a, HEADERS_COUNT>

get headers

pub fn new( payload: &'a [u8], ) -> FormingRequestResult<'a, HEADERS_COUNT, PATH_QUERY_COUNT>

for creating new request from incoming bytes and returning back where the headers of this request is end or at what position

return FormingRequestResult
pub fn path(&'a self) -> &'a str

for getting the path of the incoming request

return &str which ’a stands for the life of incoming request
pub fn method(&self) -> &'a str

parsing incoming http method

pub fn http_version(&self) -> &str

parsing incoming http version

pub fn content_length(&self) -> Option<&usize>

getting content length in headers

pub fn get_from_path_query(&self, key: &str) -> Option<&'a str>

getting data from path query for examples

  • http:://examples.com/posts?id=1 the key is id and the value is 1
  • http:://examples.com/posts?year=2024 the key is year and the value is 2024