Module server

Module server 

Modules

capsule_macros
defining all the used and imported macros for building your app struct
matcher
providing matching tech
response_interceptors

Structs

CapsuleWaterController
ContextAccessories
HttpContext
http context is a handler wrapper for http requests and operations that help providing very fast handling framework for all http requests types
ServerConfigurations
a struct for configurations of the server we could specify which port we are listening to and who is going to connect to your server and who is restricted , where the public files exist , do you need to even check on these public files or not , setting tls connection configuration specify the tls ports and threshold of encoding data algorithm and also specify the important headers to retrieve for optimizing requests while handling a lot of them

Enums

HeaderInterceptorApplyFor
MiddlewareResult

RestrictionRule
specify the strict role for the server to detect who is connecting our server and who is not

Functions

run_server
running given server configurations with Controller Root